@@ -1,4 +1,5 @@
 from typing import Any, Dict, Optional, TYPE_CHECKING
+
 if TYPE_CHECKING:
     from dataclasses import dataclass
 else:
@@ -31,11 +32,12 @@ __all__ = [
     "Step",
     "SimulationState",
     "Scenario",
+    "ScenarioDuckieSpec",
     "StateDump",
     "JPGImage",
     "DumpState",
     "MOTION_PARKED",
-    'MOTION_MOVING',
+    "MOTION_MOVING",
 ]
 
 RobotName = str
@@ -177,11 +179,18 @@ class ScenarioRobotSpec:
     description: str
     playable: bool
     configuration: RobotConfiguration
+    color: str
 
     # if not playable
     motion: Optional[NPMotion]
 
 
+@dataclass
+class ScenarioDuckieSpec:
+    color: str  # css color
+    pose: np.ndarray  # SE2
+
+
 @dataclass
 class SpawnRobot:
     playable: bool
@@ -194,8 +203,9 @@ class SpawnRobot:
 class Scenario:
     # Specification of the environments
     scenario_name: str
-    environment: object
+    environment: Any
     robots: Dict[str, ScenarioRobotSpec]
+    duckies: Dict[str, ScenarioDuckieSpec]
 
 
 description = """\
